All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 2/2] [BUGFIX] kprobes: Fix selftest to clear flags field for reusing probes
       [not found] <20100805123134.3888.4549.stgit@ltc236.sdl.hitachi.co.jp>
@ 2010-08-05 12:35 ` Masami Hiramatsu
  2010-08-05 12:56   ` Ananth N Mavinakayanahalli
  0 siblings, 1 reply; 2+ messages in thread
From: Masami Hiramatsu @ 2010-08-05 12:35 UTC (permalink / raw)
  Cc: Masami Hiramatsu, Ananth N Mavinakayanahalli, linux-kernel

Fix selftest to clear flags field for reusing probes
because the flags field can be modified by Kprobes.
This also set NULL to kprobe.addr instead of 0.

Signed-off-by: Masami Hiramatsu <masami.hiramatsu.pt@hitachi.com>
Cc: Ananth N Mavinakayanahalli <ananth@in.ibm.com>
Cc: linux-kernel@vger.kernel.org
---

 kernel/test_kprobes.c |   12 +++++++++---
 1 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/kernel/test_kprobes.c b/kernel/test_kprobes.c
index 4f10451..f8b11a2 100644
--- a/kernel/test_kprobes.c
+++ b/kernel/test_kprobes.c
@@ -115,7 +115,9 @@ static int test_kprobes(void)
 	int ret;
 	struct kprobe *kps[2] = {&kp, &kp2};

-	kp.addr = 0; /* addr should be cleard for reusing kprobe. */
+	/* addr and flags should be cleard for reusing kprobe. */
+	kp.addr = NULL;
+	kp.flags = 0;
 	ret = register_kprobes(kps, 2);
 	if (ret < 0) {
 		printk(KERN_ERR "Kprobe smoke test failed: "
@@ -210,7 +212,9 @@ static int test_jprobes(void)
 	int ret;
 	struct jprobe *jps[2] = {&jp, &jp2};

-	jp.kp.addr = 0; /* addr should be cleard for reusing kprobe. */
+	/* addr and flags should be cleard for reusing kprobe. */
+	jp.kp.addr = NULL;
+	jp.kp.flags = 0;
 	ret = register_jprobes(jps, 2);
 	if (ret < 0) {
 		printk(KERN_ERR "Kprobe smoke test failed: "
@@ -323,7 +327,9 @@ static int test_kretprobes(void)
 	int ret;
 	struct kretprobe *rps[2] = {&rp, &rp2};

-	rp.kp.addr = 0; /* addr should be cleard for reusing kprobe. */
+	/* addr and flags should be cleard for reusing kprobe. */
+	rp.kp.addr = NULL;
+	rp.kp.flags = 0;
 	ret = register_kretprobes(rps, 2);
 	if (ret < 0) {
 		printk(KERN_ERR "Kprobe smoke test failed: "



^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [PATCH 2/2] [BUGFIX] kprobes: Fix selftest to clear flags field for reusing probes
  2010-08-05 12:35 ` [PATCH 2/2] [BUGFIX] kprobes: Fix selftest to clear flags field for reusing probes Masami Hiramatsu
@ 2010-08-05 12:56   ` Ananth N Mavinakayanahalli
  0 siblings, 0 replies; 2+ messages in thread
From: Ananth N Mavinakayanahalli @ 2010-08-05 12:56 UTC (permalink / raw)
  To: Masami Hiramatsu; +Cc: linux-kernel

On Thu, Aug 05, 2010 at 09:35:11PM +0900, Masami Hiramatsu wrote:
> Fix selftest to clear flags field for reusing probes
> because the flags field can be modified by Kprobes.
> This also set NULL to kprobe.addr instead of 0.
> 
> Signed-off-by: Masami Hiramatsu <masami.hiramatsu.pt@hitachi.com>
> Cc: Ananth N Mavinakayanahalli <ananth@in.ibm.com>

Acked-by: Ananth N Mavinakayanahalli <ananth@in.ibm.com>

> Cc: linux-kernel@vger.kernel.org
> ---
> 
>  kernel/test_kprobes.c |   12 +++++++++---
>  1 files changed, 9 insertions(+), 3 deletions(-)
> 
> diff --git a/kernel/test_kprobes.c b/kernel/test_kprobes.c
> index 4f10451..f8b11a2 100644
> --- a/kernel/test_kprobes.c
> +++ b/kernel/test_kprobes.c
> @@ -115,7 +115,9 @@ static int test_kprobes(void)
>  	int ret;
>  	struct kprobe *kps[2] = {&kp, &kp2};
> 
> -	kp.addr = 0; /* addr should be cleard for reusing kprobe. */
> +	/* addr and flags should be cleard for reusing kprobe. */
> +	kp.addr = NULL;
> +	kp.flags = 0;
>  	ret = register_kprobes(kps, 2);
>  	if (ret < 0) {
>  		printk(KERN_ERR "Kprobe smoke test failed: "
> @@ -210,7 +212,9 @@ static int test_jprobes(void)
>  	int ret;
>  	struct jprobe *jps[2] = {&jp, &jp2};
> 
> -	jp.kp.addr = 0; /* addr should be cleard for reusing kprobe. */
> +	/* addr and flags should be cleard for reusing kprobe. */
> +	jp.kp.addr = NULL;
> +	jp.kp.flags = 0;
>  	ret = register_jprobes(jps, 2);
>  	if (ret < 0) {
>  		printk(KERN_ERR "Kprobe smoke test failed: "
> @@ -323,7 +327,9 @@ static int test_kretprobes(void)
>  	int ret;
>  	struct kretprobe *rps[2] = {&rp, &rp2};
> 
> -	rp.kp.addr = 0; /* addr should be cleard for reusing kprobe. */
> +	/* addr and flags should be cleard for reusing kprobe. */
> +	rp.kp.addr = NULL;
> +	rp.kp.flags = 0;
>  	ret = register_kretprobes(rps, 2);
>  	if (ret < 0) {
>  		printk(KERN_ERR "Kprobe smoke test failed: "
> 

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2010-08-05 12:56 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
     [not found] <20100805123134.3888.4549.stgit@ltc236.sdl.hitachi.co.jp>
2010-08-05 12:35 ` [PATCH 2/2] [BUGFIX] kprobes: Fix selftest to clear flags field for reusing probes Masami Hiramatsu
2010-08-05 12:56   ` Ananth N Mavinakayanahalli

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.